@@ -9,7 +9,7 @@
 ##' @export
 reduce_agegroups <- function(x, limits) {
     ret <- x[NA]
-    int <- findInterval(x, limits)
+    int <- findInterval(x, sort(limits))
     ret[!is.na(int) & int > 0] <-
       limits[int[!is.na(int) & int > 0]]
     return(ret)
